@@ -125,6 +125,10 @@ sub get_command_internal {
 
     return if $self->get('Session ID') eq "";
 
+    if (defined($options->{'DISABLE_NETWORK'}) && $options->{'DISABLE_NETWORK'}) {
+	print STDERR "Disabling the network for this command was requested but the schroot backend doesn't support this feature yet: https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=802849\n" if $self->get_conf('DEBUG');
+    }
+
     # Command to run. If I have a string, use it. Otherwise use the list-ref
     my $command = $options->{'INTCOMMAND_STR'} // $options->{'INTCOMMAND'};
 
