@@ -24,7 +24,7 @@ use strict;
 use warnings;
 
 use File::Temp qw(tempfile);
-use Sbuild qw($devnull);
+use Sbuild qw($devnull shellescape);
 
 BEGIN {
     use Exporter ();
@@ -33,7 +33,7 @@ BEGIN {
     @ISA = qw(Exporter);
 
     @EXPORT = qw(basesetup shell hold_packages unhold_packages
-                 list_packages set_package_status generate_keys);
+                 list_packages set_package_status);
 }
 
 sub basesetup ($$);
@@ -42,7 +42,6 @@ sub hold_packages ($$@);
 sub unhold_packages ($$@);
 sub list_packages ($$@);
 sub set_package_status ($$$@);
-sub generate_keys ($$);
 
 sub basesetup ($$) {
     my $session = shift;
@@ -58,39 +57,48 @@ sub basesetup ($$) {
     if ($?) {
 	# This will require root privileges.  However, this should
 	# only get run at initial chroot setup time.
-	my $groupfile = $session->get('Location') . "/etc/group";
-	system("getent group sbuild >> $groupfile");
+	$session->run_command(
+	    { COMMAND => ['groupadd', '--system', 'sbuild'],
+	      USER => 'root',
+	      STREAMIN => $devnull,
+	      STREAMOUT => $devnull,
+	      DIR => '/' });
 	if ($?) {
 	    print STDERR "E: Failed to create group sbuild\n";
 	    return $?
 	}
     }
 
+    my $build_path = '/build';
+    if (defined($session->get_conf('BUILD_PATH')) && $session->get_conf('BUILD_PATH')) {
+	$build_path = $session->get_conf('BUILD_PATH');
+    }
+
     $session->run_command(
 	{ COMMAND => ['/bin/sh', '-c',
-		      'set -e; if [ ! -d /build ] ; then mkdir -m 0775 /build; fi'],
+		      'set -e; if [ ! -d ' . (shellescape $build_path) . ' ] ; then mkdir -m 0775 ' . (shellescape $build_path) . '; fi'],
 	  USER => 'root',
 	  DIR => '/' });
     if ($?) {
-	print STDERR "E: Failed to create build directory /build\n";
+	print STDERR "E: Failed to create build directory $build_path\n";
 	return $?
     }
 
     $session->run_command(
-	{ COMMAND => ['chown', 'sbuild:sbuild', '/build'],
+	{ COMMAND => ['chown', 'sbuild:sbuild', $build_path],
 	  USER => 'root',
 	  DIR => '/' });
     if ($?) {
-	print STDERR "E: Failed to set sbuild:sbuild ownership on /build\n";
+	print STDERR "E: Failed to set sbuild:sbuild ownership on $build_path\n";
 	return $?
     }
 
     $session->run_command(
-	{ COMMAND => ['chmod', '02770', '/build'],
+	{ COMMAND => ['chmod', '02770', $build_path],
 	  USER => 'root',
 	  DIR => '/' });
     if ($?) {
-	print STDERR "E: Failed to set 0750 permissions on /build\n";
+	print STDERR "E: Failed to set 0750 permissions on $build_path\n";
 	return $?
     }
 
@@ -226,103 +234,4 @@ sub set_package_status ($$$@) {
     return $?;
 }
 
-sub generate_keys ($$) {
-    my $host = shift;
-    my $conf = shift;
-
-    my ($tmpfh, $tmpfilename) = tempfile();
-    print $tmpfh <<"EOF";
-Key-Type: RSA
-Key-Length: 1024
-Name-Real: Sbuild Signer
-Name-Comment: Sbuild Build Dependency Archive Key
-Name-Email: buildd-tools-devel\@lists.alioth.debian.org
-Expire-Date: 0
-%commit
-EOF
-    close($tmpfh);
-
-    my $gnupghome = $ENV{'GNUPGHOME'};
-    if (!$gnupghome) {
-	$gnupghome = $ENV{'HOME'};
-	if (!$gnupghome) {
-	    my @pwinfo = getpwuid($<);
-	    die "Can't get passwd entry for uid $<: $!" if (!@pwinfo);
-	    print STDERR "W: HOME not set in environment; falling back to $pwinfo[7]\n";
-	    $gnupghome = $pwinfo[7];
-	}
-	$gnupghome .= '/.gnupg';
-    }
-    if (! -d $gnupghome) {
-	mkdir $gnupghome, 0700 or die "failed to create $gnupghome";
-    }
-
-    $host->run_command(
-	{ COMMAND => ['chown', ':sbuild', $tmpfilename],
-	  USER => $conf->get('USERNAME'),
-	  DIR => '/' });
-    if ($?) {
-	print STDERR "E: Failed to set :sbuild ownership on $tmpfilename\n";
-	return $?
-    }
-    $host->run_command(
-	{ COMMAND => ['chmod', '0660', $tmpfilename],
-	  USER => $conf->get('USERNAME'),
-	  DIR => '/' });
-    if ($?) {
-	print STDERR "E: Failed to set 0660 permissions on $tmpfilename\n";
-	return $?
-    }
-
-    my @command = ('gpg', '--no-options', '--pinentry-mode', 'loopback', '--passphrase-file', '/dev/null', '--no-default-keyring', '--batch', '--gen-key',
-                   $tmpfilename);
-    $host->run_command(
-        { COMMAND => \@command,
-	  USER => $conf->get('BUILD_USER'),
-          PRIORITY => 0,
-          DIR => '/'});
-    if ($?) {
-        return $?;
-    }
-
-    # export keys
-    @command = ('gpg', '--batch', '--yes', '--export-secret-keys',
-	        '--output', $conf->get('SBUILD_BUILD_DEPENDS_SECRET_KEY'),
-	        'buildd-tools-devel@lists.alioth.debian.org');
-    $host->run_command(
-	{ COMMAND => \@command,
-	  USER => $conf->get('BUILD_USER'),
-	  PRIORITY => 0,
-	  DIR => '/'});
-    if ($?) {
-	print STDERR "E: Unable to export secret key.";
-	return $?;
-    }
-
-    @command = ('gpg', '--batch', '--yes', '--export',
-	        '--output', $conf->get('SBUILD_BUILD_DEPENDS_PUBLIC_KEY'),
-	        'buildd-tools-devel@lists.alioth.debian.org');
-    $host->run_command(
-	{ COMMAND => \@command,
-	  USER => $conf->get('BUILD_USER'),
-	  PRIORITY => 0,
-	  DIR => '/'});
-    if ($?) {
-	print STDERR "E: Unable to export public key.";
-	return $?;
-    }
-
-    # Keys needs to be readable by 'sbuild' group.
-    @command = ('chmod', '640',
-                $conf->get('SBUILD_BUILD_DEPENDS_SECRET_KEY'),
-                $conf->get('SBUILD_BUILD_DEPENDS_PUBLIC_KEY'));
-    $host->run_command(
-        { COMMAND => \@command,
-	  USER => $conf->get('BUILD_USER'),
-          PRIORITY => 0,
-          DIR => '/'});
-
-    return $?;
-}
-
 1;
